summaryrefslogtreecommitdiff
path: root/src/script/api/script_industrytypelist.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/script/api/script_industrytypelist.cpp')
-rw-r--r--src/script/api/script_industrytypelist.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/script/api/script_industrytypelist.cpp b/src/script/api/script_industrytypelist.cpp
index fbbe6bcf2..c72fabcaa 100644
--- a/src/script/api/script_industrytypelist.cpp
+++ b/src/script/api/script_industrytypelist.cpp
@@ -7,15 +7,15 @@
* See the GNU General Public License for more details. You should have received a copy of the GNU General Public License along with OpenTTD. If not, see <http://www.gnu.org/licenses/>.
*/
/** @file script_industrytypelist.cpp Implementation of AIIndustryTypeList. */
#include "../../stdafx.h"
#include "script_industrytypelist.hpp"
#include "../../industry.h"
-AIIndustryTypeList::AIIndustryTypeList()
+ScriptIndustryTypeList::ScriptIndustryTypeList()
{
for (int i = 0; i < NUM_INDUSTRYTYPES; i++) {
- if (AIIndustryType::IsValidIndustryType(i)) this->AddItem(i);
+ if (ScriptIndustryType::IsValidIndustryType(i)) this->AddItem(i);
}
}
@@ -7,15 +7,15 @@
* See the GNU General Public License for more details. You should have received a copy of the GNU General Public License along with OpenTTD. If not, see <http://www.gnu.org/licenses/>.
*/
-/** @file script_industrytypelist.cpp Implementation of AIIndustryTypeList. */
+/** @file script_industrytypelist.cpp Implementation of ScriptIndustryTypeList. */
#include "../../stdafx.h"
#include "script_industrytypelist.hpp"